Module: Falcon::Environment::Rackup
- Defined in:
- lib/falcon/environment/rackup.rb
Overview
Provides an environment for hosting loading a Rackup ‘config.ru` file.
Instance Method Summary collapse
-
#middleware ⇒ Object
Build the middleware stack for the rack application.
-
#rack_app ⇒ Object
Parse and load the rack application from the rackup file.
-
#rackup_path ⇒ Object
The path to the rackup configuration file.
Instance Method Details
#middleware ⇒ Object
Build the middleware stack for the rack application.
27 28 29 |
# File 'lib/falcon/environment/rackup.rb', line 27 def middleware ::Falcon::Server.middleware(rack_app, verbose: verbose, cache: cache) end |
#rack_app ⇒ Object
Parse and load the rack application from the rackup file.
21 22 23 |
# File 'lib/falcon/environment/rackup.rb', line 21 def rack_app ::Protocol::Rack::Adapter.parse_file(rackup_path) end |
#rackup_path ⇒ Object
The path to the rackup configuration file.
15 16 17 |
# File 'lib/falcon/environment/rackup.rb', line 15 def rackup_path File.("config.ru", root) end |