Module: Falcon::Environment::Virtual
- Includes:
- Configured
- Defined in:
- lib/falcon/environment/virtual.rb
Overview
Provides an environment for running virtual hosts with front-end proxy and redirect services.
Instance Method Summary collapse
-
#bind_insecure ⇒ Object
The URI to bind the ‘HTTP` -> `HTTPS` redirector.
-
#bind_secure ⇒ Object
The URI to bind the ‘HTTPS` -> `falcon host` proxy.
-
#falcon_path ⇒ Object
The path to the falcon executable from this gem.
-
#name ⇒ Object
The name of the virtual host service.
-
#service_class ⇒ Object
The service class to use for the virtual host.
-
#timeout ⇒ Object
The connection timeout to use for incoming connections.
Methods included from Configured
#configuration, #configuration_paths, #resolved_configuration_paths
Instance Method Details
#bind_insecure ⇒ Object
The URI to bind the ‘HTTP` -> `HTTPS` redirector.
34 35 36 |
# File 'lib/falcon/environment/virtual.rb', line 34 def bind_insecure "http://[::]:80" end |
#bind_secure ⇒ Object
The URI to bind the ‘HTTPS` -> `falcon host` proxy.
29 30 31 |
# File 'lib/falcon/environment/virtual.rb', line 29 def bind_secure "https://[::]:443" end |
#falcon_path ⇒ Object
The path to the falcon executable from this gem.
45 46 47 |
# File 'lib/falcon/environment/virtual.rb', line 45 def falcon_path File.("../../../bin/falcon", __dir__) end |
#name ⇒ Object
The name of the virtual host service.
24 25 26 |
# File 'lib/falcon/environment/virtual.rb', line 24 def name service_class.name end |
#service_class ⇒ Object
The service class to use for the virtual host.
18 19 20 |
# File 'lib/falcon/environment/virtual.rb', line 18 def service_class Service::Virtual end |
#timeout ⇒ Object
The connection timeout to use for incoming connections.
39 40 41 |
# File 'lib/falcon/environment/virtual.rb', line 39 def timeout 10.0 end |