Class: Rackup::Handler::Falcon

Inherits:
Falcon::Rackup::Handler show all
Defined in:
lib/rackup/handler/falcon.rb

Overview

Sinatra (and possibly others) try to extract the name using the final part of the class path, so we define a new class in the Rack::Handler namespace that inherits from Falcon::Rackup::Handler, that follows that convention.

Constant Summary

Constants inherited from Falcon::Rackup::Handler

Falcon::Rackup::Handler::SCHEME

Method Summary

Methods inherited from Falcon::Rackup::Handler

#close, endpoint_for, #initialize, run, #stop, to_s

Constructor Details

This class inherits a constructor from Falcon::Rackup::Handler