Module: Falcon::Environment::Cluster
- Includes:
- Server
- Defined in:
- lib/falcon/environment/cluster.rb
Overview
Provides an environment for hosting a cluster of Falcon server workers, where each worker binds its own endpoint.
Instance Method Summary collapse
-
#service_class ⇒ Object
The service class to use for the cluster.
-
#url ⇒ Object
The host that this server will receive connections for.
Methods included from Server
#authority, #cache, #client_endpoint, #endpoint, #endpoint_options, #make_server, #prepare_worker!, #timeout, #verbose
Instance Method Details
#service_class ⇒ Object
The service class to use for the cluster.
17 18 19 |
# File 'lib/falcon/environment/cluster.rb', line 17 def service_class Service::Cluster end |
#url ⇒ Object
The host that this server will receive connections for.
22 23 24 |
# File 'lib/falcon/environment/cluster.rb', line 22 def url "http://[::]:0" end |